
/** 
 * Une connection URL pour le protocole DNS (une partie).
 *
 * <p>La syntaxe d'une URL DNS est :
 *
 * <pre>
 * dns:&lt;url&gt;?{commande}
 * </pre>
 *
 * <p>par exemple :
 *
 * <p><code>
 * dns://univ-paris13.fr?MX<br>
 * </code>
 *
 * 
 * <p>Exemple d'utilisation dans un code :
 *
 * <pre>
 * URL url = new URL("dns://www.univ-paris13.fr");
 * DnsURLConnection dnsConnection = (DnsURLConnection)url.openConnection();
 * DnsEntry dnsEntry = dnsConnection.getContent();
 * </pre>
 *
 * <p>Exemples :
 * 
 * <dl>
 * 
 * <dt>Requete d'une conversion IP / nom de machine
 * <dd><code>dns://www.univ-paris13.fr</code>
 * <dd><code>dns://www.univ-paris13.fr?A</code>
 *
 * <dt>Requete de recherche du serveur de mail en envoi
 * <dd><code>dns://univ-paris13.fr?MX</code>
 *
 */

package up13.dns;

import java.net.*;
import java.io.*;

public class DnsURLConnection extends URLConnection {

    public DnsURLConnection(URL url) throws MalformedURLException {
		super(url);
		setContentHandlerFactory(new DnsContentHandlerFactory());
    }	

	public void connect() {
	}

   public InputStream getInputStream() {
		return null;
   }

   public String getHeaderField(String name) {
	if (name.equals("content-type")) return "dns";
	return null;
    }

}







